python-evecentral
=============

Super simple module that hits 2 external APIs. 

It uses `Fuzzworks <[https://www.fuzzwork.co.uk/tools/api-typename-to-typeid/>`_ to get 
the typeID from a typeName. 

It then pulls prices from the `EVE-Central API <http://eve-central.com/home/develop.html>`_
and caches them in memory
